@@ -16,6 +16,7 @@
 import functools
 import re
 import time
+from urllib import parse
 import uuid
 
 import requests
@@ -25,7 +26,6 @@ from keystoneauth1 import loading as keystone
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import versionutils
-from six.moves.urllib.parse import urlencode
 
 from neutron_lib._i18n import _
 from neutron_lib.exceptions import placement as n_exc
@@ -375,7 +375,7 @@ class PlacementAPIClient(object):
             filters['in_tree'] = in_tree
         if uuid:
             filters['uuid'] = uuid
-        url = '%s?%s' % (url, urlencode(filters))
+        url = '%s?%s' % (url, parse.urlencode(filters))
         return self._get(url).json()
 
     @_check_placement_api_available
