@@ -15,14 +15,13 @@
 
 import mock
 import netaddr
-import six
 import testtools
 
 from neutron_lib.api import converters
 from neutron_lib import constants
 from neutron_lib import exceptions as n_exc
 from neutron_lib.tests import _base as base
-from neutron_lib.tests import _tools as tools
+from neutron_lib.tests import tools
 
 
 class TestConvertToBoolean(base.BaseTestCase):
@@ -231,7 +230,7 @@ class TestConvertStringToCaseInsensitive(base.BaseTestCase):
 
     def test_convert_string_to_lower(self):
         result = converters.convert_string_to_case_insensitive(u"THIS Is tEsT")
-        self.assertIsInstance(result, six.string_types)
+        self.assertIsInstance(result, str)
 
     def test_assert_error_on_non_string(self):
         for invalid in [[], 123]:
