@@ -38,13 +38,13 @@ class HackingTestCase(base.BaseTestCase):
         return check_fns
 
     def test_factory(self):
-        self.assertTrue(len(self._get_factory_checks(checks.factory)) > 0)
+        self.assertGreater(len(self._get_factory_checks(checks.factory)), 0)
 
     def test_neutron_lib_factory(self):
         lib_checks = self._get_factory_checks(checks._neutron_lib_factory)
         other_checks = self._get_factory_checks(checks.factory)
 
-        self.assertTrue(len(lib_checks) > 0)
+        self.assertGreater(len(lib_checks), 0)
 
         if other_checks:
             for other_check in other_checks:
@@ -87,24 +87,6 @@ class HackingTestCase(base.BaseTestCase):
         self.assertLinePasses(f, '# with contextlib.nested():', '')
         self.assertLinePasses(f, 'print("with contextlib.nested():")', '')
 
-    def test_check_python3_xrange(self):
-        f = checks.check_python3_xrange
-        self.assertLineFails(f, 'a = xrange(1000)')
-        self.assertLineFails(f, 'b =xrange   (   42 )')
-        self.assertLineFails(f, 'c = xrange(1, 10, 2)')
-        self.assertLinePasses(f, 'd = range(1000)')
-        self.assertLinePasses(f, 'e = six.moves.range(1337)')
-
-    def test_no_basestring(self):
-        f = checks.check_no_basestring
-        self.assertLineFails(f, 'isinstance(x, basestring)')
-        self.assertLinePasses(f, 'isinstance(x, BaseString)')
-
-    def test_check_python3_iteritems(self):
-        f = checks.check_python3_no_iteritems
-        self.assertLineFails(f, "d.iteritems()")
-        self.assertLinePasses(f, "six.iteritems(d)")
-
     def test_no_mutable_default_args(self):
         self.assertEqual(1, len(list(checks.no_mutable_default_args(
             " def fake_suds_context(calls={}):"))))
@@ -188,6 +170,14 @@ class HackingTestCase(base.BaseTestCase):
             "self.assertEqual(None, A)"))), 1)
         self.assertEqual(len(list(checks.assert_equal_none(
             "self.assertEqual(None, A)  # Comment"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual((None, None), A)"))), 0)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual((None, None), A)  # Comment"))), 0)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual(A, (None, None))"))), 0)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "self.assertEqual(A, (None, None))  # Comment"))), 0)
         self.assertEqual(len(list(checks.assert_equal_none(
             "assertIsNot(A, None)"))), 1)
         self.assertEqual(len(list(checks.assert_equal_none(
@@ -196,6 +186,14 @@ class HackingTestCase(base.BaseTestCase):
             "assertIsNot(None, A)"))), 1)
         self.assertEqual(len(list(checks.assert_equal_none(
             "assertIsNot(None, A)  # Comment"))), 1)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot((None, None), A)"))), 0)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot((None, None), A)  # Comment"))), 0)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot(A, (None, None))"))), 0)
+        self.assertEqual(len(list(checks.assert_equal_none(
+            "assertIsNot(A, (None, None))  # Comment"))), 0)
         self.assertEqual(
             len(list(checks.assert_equal_none("self.assertIsNone(A)"))), 0)
         self.assertEqual(
